
# q-expansion of newform 4338.2.a.w, downloaded from the LMFDB on 01 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 4338
weight = 2
poly_data = [158, -126, -121, 95, 26, -20, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0], 1], [[-6, 1, 1, 0, 0, 0, 0], 1], [[536, -436, -251, 162, 24, -10, -1], 38], [[-1276, -224, 1219, 116, -284, -2, 15], 38], [[-1397, 102, 1112, -25, -231, 6, 12], 19], [[3224, 46, -2597, -72, 534, -4, -27], 38], [[-5074, 242, 4067, 26, -842, 12, 43], 38]]

hecke_ring_character_values = None
aps_data = [[1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, 1, 0, 0, 0], [1, 0, 0, 0, 0, -1, 0], [-1, 0, -1, 0, 1, -1, 0], [2, -1, 0, 0, 0, 0, 0], [-1, 0, 0, 1, 0, 0, -1], [1, 1, 0, 0, 0, -1, 0], [0, 0, 0, 1, 0, 1, 1], [0, 0, 1, 0, -1, 0, 0], [1, 0, -1, 0, -1, 1, 0], [3, 0, 0, -1, 0, 0, 1], [0, 0, -1, -2, -1, -2, 0], [2, 0, 2, 1, 0, 3, 1], [3, 0, -1, -1, -2, 1, 1], [2, 0, 1, -2, 0, -1, -1], [0, 0, 0, -2, -1, 1, 1], [4, 0, -1, 0, -1, 0, -2], [-1, 0, -3, 1, 2, -3, -1], [1, 1, 0, -2, 0, -1, 0], [2, 0, 0, 0, 0, 0, -2], [5, 0, 1, 1, 0, 3, 1], [-1, 2, 1, -1, 0, -1, -1], [-4, -1, 0, 0, 2, -2, -2], [3, 0, -2, 1, 0, 2, 0], [-8, 0, -2, 2, -2, 2, 0], [1, 2, 3, 0, -1, 1, 0], [2, 0, 2, -4, -1, -1, -1], [8, 1, -2, -2, 0, -2, 0], [-2, 0, 1, 0, 3, 0, 0], [3, 0, -3, -2, 1, -3, 0], [-1, 0, 2, 0, 0, 1, 2], [-2, 1, 0, -2, 0, -4, -2], [3, -1, 0, 2, 2, 1, 0], [-4, -2, -2, -2, -2, 2, 0], [2, 0, 0, -2, 1, 1, 1], [5, 0, 0, 3, 0, 2, 1], [2, 0, 2, -3, -2, 1, 1], [5, 1, 4, 0, 2, -1, 0], [-2, 0, 0, 0, -2, 0, 0], [-3, 0, -2, 0, 0, 3, 0], [4, 0, 0, 4, -2, 4, 0], [7, 0, 1, 1, 2, -3, 1], [0, 0, -1, 2, 2, -3, -3], [2, -2, -4, -4, 0, -2, 2], [1, -2, -1, -2, 3, -1, 0], [4, -2, -2, -2, -2, -2, 0], [0, 0, 0, 0, -1, -5, -1], [3, 0, 0, -2, 0, 1, 0], [8, -2, 1, 2, -3, 2, 2], [4, 0, 0, 2, -2, 6, 4], [-2, -2, 0, 0, 2, 0, 2], [1, 0, 0, 0, 0, 0, 0], [-2, 0, -4, -2, -1, -5, -3], [4, 0, -4, 2, 0, 0, -2], [6, -2, 4, -1, -2, 3, 1], [6, 0, 4, -4, 2, 0, 2], [3, 0, 5, 1, 4, 1, 1], [0, 0, 0, -6, 0, 0, -2], [-2, 4, -1, 0, -1, -2, -2], [-10, 2, -2, 1, 0, -1, -1], [6, 0, -2, 0, 2, -2, 0], [-5, 1, 1, 2, 3, -1, 0], [-4, 0, 0, 5, -2, 3, 1], [-1, 0, -4, 1, 2, 2, 0], [2, 0, -2, 4, 0, 0, -2], [-10, 2, 2, 4, 2, -2, -4], [-5, 0, 2, 1, 1, 3, -1], [-2, 2, 0, 6, 5, -3, -3], [6, 2, 3, 4, -3, 0, 0], [4, -1, 0, -6, -4, 2, 0], [2, 0, 2, 0, 2, -2, 2], [-9, 0, 4, 6, 2, 5, -2], [-7, -2, 2, 1, -2, 4, 5], [9, -3, 0, -2, -2, 3, 0], [-4, -2, -3, 1, -1, -3, -1], [-6, -2, 2, 4, -2, 6, 0], [-1, 2, 0, -1, -4, -4, -1], [6, 0, 1, 4, 1, 6, 0], [-4, -2, 2, -6, -4, -2, 0], [3, 0, 2, -2, 0, 7, 0], [8, 2, -1, -2, 3, -6, 0], [-1, -1, 0, 0, -2, -3, -4], [-6, 4, 2, 4, 2, -2, -2], [7, -2, 6, 2, 2, 7, 4], [7, -2, 1, 2, -5, 1, -2], [-3, -4, 0, -7, -6, 4, 3], [-12, -2, -1, 2, -3, 4, 0], [-4, 2, -2, -2, 2, -2, 4], [-13, 2, -4, 2, 0, -1, 0], [-3, 2, 5, 1, 2, -3, -3], [-4, 0, 0, 4, 6, -2, -2], [-2, -2, 2, 2, -3, 7, 5], [7, -2, 5, -1, 4, 3, -1], [1, -1, 0, -4, 4, -1, -2], [-5, -1, 1, -4, -1, -1, 4], [-2, -2, 1, 0, 1, 6, 2], [-10, -1, 4, 4, 2, 4, -4], [4, 2, 0, -2, -4, -2, 0], [-10, 0, -2, -2, 0, 0, 0], [0, 0, 3, -1, 3, 3, 3], [3, 0, -2, -1, 3, -1, 1], [-4, -2, 4, 4, 3, 7, -1], [0, -2, -1, -2, 3, -2, 0], [10, 2, 1, -7, 5, -9, -1], [-4, 0, -2, -2, -2, 4, 4], [7, 0, -1, -4, 3, 1, 2], [-5, -2, 4, 5, 4, 8, 1], [-7, 3, -3, 0, -5, 5, -2], [-6, 0, -6, 4, -1, 1, 3], [-2, -4, 0, -4, -3, 7, 5], [10, 3, 0, 2, 2, 0, -4], [6, 2, -5, -4, 3, -6, 0], [4, 2, 9, -3, -1, 3, -1], [-7, 2, -4, 0, -4, -5, 6], [2, -2, 2, 4, -2, 4, 2], [-7, 0, -1, 5, 2, 5, -1], [-7, -3, -4, 0, 6, -1, 2], [8, 2, 4, -6, -4, 6, 4], [0, -2, 2, -2, -3, 1, 3], [8, -1, 4, 8, -4, 6, 0], [8, -2, 5, -2, 4, 1, -1], [10, -2, 6, -4, 2, 6, 0], [-10, 4, -4, 0, 3, -3, 1], [-8, 4, -6, 0, 4, -6, -2], [-18, 0, 2, -8, -2, -2, 0], [11, 0, 2, -5, -6, 4, 1], [1, 4, 5, -5, 2, -3, -3], [0, 0, 0, 4, 0, -4, 4], [0, 4, -4, 0, 0, 2, -2], [1, 0, -5, -5, -2, -5, -3], [0, 0, 0, -4, 0, -4, 0], [-7, -4, 4, 8, -2, 5, 0], [14, 3, 6, -2, -4, 4, 0], [-13, -2, -6, -3, 2, -8, 1], [-18, 4, -8, 4, -2, -6, 0], [-16, 2, 3, -2, 1, 8, 0], [-11, 0, 1, -1, 0, 11, 5], [6, -2, -2, 4, 2, -6, -4], [3, 2, -2, -3, -2, -8, -7], [16, -2, 6, -7, -4, 5, -1], [26, -2, 3, 0, 3, 6, 2], [2, -2, 2, -8, 5, 1, 1], [1, -2, -4, 10, 2, -3, 0], [10, -2, 7, -2, 1, 6, 4], [5, -2, 1, 3, 2, -3, -1], [13, -2, -2, -9, -2, -2, -1], [22, 0, 1, -8, 3, -4, 2], [2, 2, 6, -3, 6, -7, -5], [16, 2, 6, 1, -2, 9, -1], [-10, -2, -1, -6, 3, -4, 6], [-2, 4, 6, 0, 0, 2, 0], [13, 2, 1, 3, 4, -1, -5], [10, -2, 2, 2, 4, 2, 4], [-17, 1, -2, 0, -6, 1, 0], [0, -2, 0, 0, 0, 8, -2], [-6, -4, 0, -2, 5, 5, 1], [8, -1, -6, 4, 0, 2, -2], [-2, 2, -1, 4, 3, 8, 4], [6, -2, 2, 4, 4, 0, -2], [5, 4, 5, -2, -5, 7, 0], [12, -3, -4, -8, 2, 2, 2], [-4, 0, -8, 0, -4, 0, 0], [-11, -6, -2, -4, 2, 1, 0], [11, 6, 2, 7, 4, -4, -1], [-1, 1, 0, 2, -4, -3, 4], [0, 4, 0, 6, 1, -5, -3], [-10, 5, -2, 2, 0, 0, 0], [-3, 0, -2, 3, -4, -2, 0], [-24, -2, -2, 4, 0, -2, 2], [9, -2, -5, -2, -1, -7, 4], [15, 4, 0, -1, 4, -8, -7], [-9, 0, 1, -1, -6, 3, -1], [0, 6, -4, -6, -4, -8, 0], [-24, 6, -2, 6, -1, -1, -5], [-32, -1, -4, 4, 2, -6, -2], [15, 0, -1, 1, -2, 3, 1], [0, -6, -7, -6, -5, 0, 0], [-5, 0, -10, 6, -2, -1, 2], [21, -6, 6, -3, 2, 4, 1], [-7, 0, 3, -1, 0, -1, -1], [-13, 4, 4, -2, 2, 3, 0], [10, -3, 2, -2, 0, -8, 0], [-4, 0, -2, -2, -4, 2, -2], [-1, -3, 7, -6, -5, 7, 4], [3, 4, 3, 5, 4, 1, 3], [13, -2, 0, -1, -4, 2, -1], [-15, -4, -3, 3, 4, 3, 5], [-12, 0, -4, -6, 0, -4, 4], [1, 0, -5, 1, 0, -5, -5], [-12, 0, -4, -2, 10, -10, -4], [11, 2, -10, 2, 4, -17, -2], [-23, -1, -7, 6, -1, -3, -2], [14, 2, 1, 6, -4, -1, -7], [4, -2, 10, 2, -7, 13, -1], [-10, 0, 3, 8, -5, 10, -2], [-6, -2, 5, 0, 1, 4, -4], [12, 0, 7, 8, -3, 10, 4], [14, 2, 5, 4, -3, 2, 0], [-33, 0, -1, 5, 2, 3, 3], [5, 2, 1, 11, 1, 2, 2], [-1, -2, 0, 0, -2, 3, 0], [-2, -2, 1, -12, 3, -12, -2], [0, -2, -6, 10, -2, 0, 0], [7, -2, 1, 9, 2, 7, 1], [-4, -4, -9, -8, -4, -7, 5], [21, 0, 0, -6, 2, 3, -2], [31, 0, -1, 2, 5, -3, 0], [-1, 0, 2, 7, 0, 12, 1], [-14, 0, -2, -17, 2, -9, -1], [20, 2, 0, -10, -6, 6, -2], [-17, 0, 4, 3, 1, 3, 5], [4, 0, -6, 2, 9, -3, -5], [23, 0, -2, 10, 0, 3, 2], [0, -2, -6, 3, -4, 9, -3], [-24, 2, -2, 2, 1, -9, -5], [8, 0, 12, 0, -1, 15, -1], [-1, 4, -4, 1, 4, 0, 3], [21, 0, 1, 1, 4, 1, -3], [0, -2, 8, 6, -8, 6, 4], [-2, 5, 4, 6, 2, 8, 0], [-2, 4, 4, 6, -1, 7, 3], [22, -5, 2, 0, 4, 0, 4], [-1, -2, 5, 4, -1, 5, -2], [9, 0, -4, 6, -4, 3, -4], [25, 0, 8, 3, 0, 14, 5], [7, -4, 2, 7, 0, 4, -3], [-2, 2, 6, -7, 8, -3, 7], [-8, 0, 4, 6, 2, 4, 2], [37, 2, 5, 5, -2, 9, 5], [15, 0, -8, 3, 0, -12, 1], [4, 2, 3, -13, 1, -3, 1], [-28, 0, -4, 10, -2, 0, 2], [0, 5, -6, 2, 6, -2, 0], [11, 1, 4, 2, -2, 9, 2], [-13, 0, -1, 13, 2, 11, 3], [-12, -4, 0, 6, 0, 0, 0], [-8, 4, -2, -12, 1, -7, -1], [13, -2, -1, -11, 0, -11, 1], [-33, 3, 2, -2, -2, -7, 0], [6, -4, 0, -4, 4, -14, -4], [17, -5, -11, 2, -1, 1, -2], [0, -6, -6, -12, -3, -1, 1], [11, 4, 16, -1, 4, 4, 5], [8, -8, 5, -6, 1, 6, 0], [-2, 0, 4, -2, -2, 6, 2], [0, -4, 6, 0, -2, -4, 4], [1, -2, -1, 7, -6, 13, 7], [10, 4, 2, 10, 2, -4, 4], [-20, 4, 4, 9, 2, -1, -7], [-2, 0, -3, 10, 13, -8, 0], [2, 7, 2, -2, -6, 4, -2], [-10, 2, 4, -12, -4, 2, 8], [4, 8, 10, 2, -2, -4, -2], [6, 0, -4, 4, -8, 10, 0], [-3, -4, 4, 8, 4, 1, 0], [17, 0, 10, -1, 6, -2, -3], [18, 0, 6, 6, -2, 8, 0], [0, -2, 13, -8, 2, -3, -5], [7, -8, -8, 9, 2, -2, -4], [5, 4, 9, 9, -4, 3, -3], [-4, 2, -12, 4, -7, -3, 1], [14, 0, -5, 6, -7, -6, 2], [12, 0, -8, 10, 8, -12, -6], [20, -4, 8, -14, -6, 6, 4], [-7, 2, -5, 5, -6, 5, -3], [-16, 4, -4, 2, 0, 6, -6], [19, -2, 0, -9, 2, -4, 3], [8, -4, 2, -18, 0, 8, 4], [-16, 4, 6, 2, 4, 8, -4], [-22, 2, 1, 6, -1, 6, -6], [4, -2, -8, 8, 2, -6, -4], [18, 2, 0, 0, -6, 6, 10], [30, 2, -2, -6, -1, 5, -1], [3, 4, 6, -7, 1, -5, 3], [-6, 4, -2, 8, -7, 9, -1], [37, -2, -1, -5, -2, 5, 7], [24, 3, -4, -8, -4, 6, -8], [-36, 6, 4, -2, 0, -4, -2], [-33, -2, 5, 6, -3, 11, 0], [-9, -1, 4, -4, -10, 9, 4], [-15, 0, 7, 3, 8, -5, -5], [-17, -2, 3, 3, 6, 5, -1], [12, 2, 6, 4, 4, -4, 2], [43, 0, -1, -9, 2, 1, -1], [-18, 0, -2, -15, 0, -7, -3], [-12, -2, -12, -6, 0, -8, -6], [22, 4, 8, 8, 2, -4, 0], [-10, -8, -8, -6, -1, -1, -1], [-18, -1, 6, 12, 8, 8, 4], [16, -2, -3, 8, 4, -9, 1], [7, 6, -11, -6, -1, -11, 2], [-12, -4, -11, -2, -5, 0, -4], [-2, 4, 2, -4, -6, 10, 4], [16, 4, 1, -6, -1, 0, 0], [-14, 0, -6, 12, 8, 0, 4], [5, 0, -8, -4, 4, -9, 4], [-9, 0, 2, -13, -1, -13, 5], [-15, 8, -3, 4, 7, -3, -8], [-1, -4, 1, -13, 0, 5, -1], [12, 6, 6, 10, 2, 0, -4], [32, 4, 4, 10, -6, 12, 4], [-19, 6, -9, 10, 1, -7, 2], [-30, -4, 0, -12, 0, 2, 0], [-3, -4, -1, 1, 8, 3, 5], [-22, 2, -8, 8, -4, -4, -2], [9, 2, 4, 8, 6, 7, -10], [-16, 5, -10, 2, 8, -6, -4], [-3, -1, 2, 10, 6, 3, 0], [10, 2, 6, -8, 0, -10, -4], [2, 0, -2, 8, 10, -6, 2], [15, 0, 4, -17, -7, 3, 5], [38, 3, 0, 0, -2, 0, 0], [18, -2, -2, 17, 0, 3, 3], [1, -8, -5, 5, 0, 3, 3], [-5, 0, 8, 13, 11, 9, 5], [13, -6, -4, 2, 2, -7, -4], [-18, 4, 2, -4, -2, 2, 6], [14, 8, 0, 0, 2, -14, 0], [0, 0, 3, -2, 5, 8, 6], [-4, 4, -14, 3, 2, -19, -5], [-1, 4, 16, -3, 3, 1, -3], [-12, 0, -2, 10, 4, 0, -2], [-23, -6, 4, -6, -2, -1, -4], [0, -2, -3, 2, -5, 8, 0], [-21, 2, -2, 9, 6, 0, 0], [14, 2, -8, -10, -2, -10, 0], [-13, -1, 4, -4, -4, 13, 6], [0, -2, 8, 9, 2, 19, -1], [-14, -8, 8, 4, 2, 8, -4], [15, 2, 10, -1, 6, -4, 3], [-16, 6, 4, -10, 6, -8, 2], [25, 2, 1, -4, -11, 13, 10], [9, -10, 6, 0, -4, 3, 8], [-17, 4, 7, -11, -4, -7, 3], [-10, 0, -10, 12, 5, -11, -7], [-8, -4, -12, -6, -6, -2, 8], [17, 2, 2, 11, 10, -4, -5], [-8, -6, 2, 10, 4, 6, 6], [24, -4, -2, 6, 4, 0, -2], [26, 3, -2, 8, -2, 8, 0], [16, 0, 1, 6, -5, 0, -6], [2, -2, -10, 0, -14, 2, 2], [17, -6, 6, -2, -6, 5, 2], [-8, -2, -10, -8, -4, -6, -2], [11, 4, 6, 12, -4, 17, 2], [0, -1, 8, -12, 0, 14, 4], [-11, -3, 2, 0, -6, 15, -4], [3, 2, -11, 15, 2, -9, 1], [21, -6, -7, 1, 0, -1, 1], [12, -4, -10, 5, 10, -1, 1], [32, 4, -6, -2, -6, -4, 4], [3, 6, -2, 9, -8, 14, 0], [22, 0, 8, -18, -5, 7, -1], [-20, -1, -8, 4, 4, 2, 0], [-21, -2, 0, -1, 6, 0, 3], [26, 0, 6, -5, -2, 13, -1], [-6, 6, 4, 4, -9, -7, -5], [24, 5, -2, -6, 2, -6, 0], [-4, 6, 10, 9, -8, -5, -1], [14, -2, -7, 4, -9, 8, 10], [-8, 9, 2, 2, -6, -14, -8], [56, -6, 13, -15, 3, 5, 3], [-6, -4, -16, 4, 1, -17, -5], [1, -1, -7, 4, -3, 13, 8], [-8, 6, -4, -2, -8, -8, -2], [-7, 2, 6, -1, 17, -7, -9], [13, 4, -1, 2, -1, -13, -4], [-24, 2, -10, 2, -8, -2, -6], [17, -2, 15, -1, 10, 9, 3], [10, -10, -7, 7, -5, 3, -7], [-21, -6, -1, -9, 2, 5, 3], [28, 0, 10, -6, 6, -6, -8], [20, -2, -2, 0, 5, 3, -7], [-28, -6, -5, 16, 1, 6, 6], [-4, -2, 8, -4, -9, 15, -1], [-5, -6, -13, -15, 0, -7, 3], [-10, -2, 1, 12, 9, 0, 0], [10, 1, -2, 14, -2, 12, 10], [8, 2, 0, 10, 8, -8, -6], [9, 2, -6, 11, -3, 1, 3], [0, 2, -5, -2, -15, 4, 0], [14, -4, -4, -6, 3, 15, -1], [46, 2, 3, 0, 3, -6, -2], [0, -4, -10, -6, 0, -8, 0], [-22, 10, 0, 4, -4, -6, 0], [4, -4, -16, 0, 0, -4, 4], [47, 6, 8, 9, -4, 6, 5], [10, -2, 2, -8, -2, 2, -4], [20, 4, 2, 6, -4, -8, -4], [-2, 0, -8, 4, 2, -6, -16], [-16, -2, -6, 6, 2, 2, 4], [6, 4, 4, 2, 1, 1, 3], [26, 0, 7, -5, -3, -9, -5], [29, -4, -11, 1, 4, 5, -3], [-40, 0, -2, 6, -6, 8, 0], [11, 6, 8, -4, 2, 3, 8], [6, 1, 4, -18, -8, -8, -2], [12, 0, 10, 6, -2, 2, -2], [10, 4, 0, -6, -1, -7, -5], [4, 0, -11, -8, -17, -2, 8], [6, 5, -8, 0, 2, -16, -4], [-20, -2, -4, 2, -5, 9, 9], [-2, -5, -14, 12, 12, -20, -8], [-24, -4, 14, 10, 2, 6, 4], [-27, -2, 4, 12, 6, -3, -8], [48, -3, 10, 0, -2, 10, 0], [28, -2, -5, -2, -5, -2, 0], [-7, -1, -2, 16, -2, 19, 2], [1, 2, -4, 2, 8, -13, -16], [22, -2, -9, -12, -1, -20, 4], [42, -4, 6, -12, 8, -8, 4], [-14, 2, -6, 10, -1, -7, 1], [2, 2, 2, 2, 16, -14, -4], [-44, 4, -8, 6, -4, -12, -6], [10, -2, 2, -12, 18, -14, -2], [18, -2, 19, 9, -11, 23, 7], [-8, 4, -10, 2, -4, 4, 2], [26, 6, -3, 0, -1, -16, -6], [-3, -5, 0, -4, 14, -13, 2], [-14, 4, -2, 0, -8, 0, -4], [-12, -8, 1, 6, 11, -4, -6], [15, 5, 2, 2, 6, -3, -6], [-22, 6, 12, -6, 1, 13, 5], [-9, 6, -7, -3, -5, -16, -2], [-30, 10, -12, 12, 8, -2, -6], [-3, 2, -2, 10, 0, -3, 4], [-16, 4, 3, 14, 1, -4, 2], [15, 4, -5, -11, 6, -25, -7], [3, 6, -5, 1, -4, -3, 3]]
